#
# spec file for package wf-recorder
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018 Michael Aquilina
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wf-recorder
Version:        0.4.0+git0
Release:        1.1
Summary:        Utility program for screen recording of wlroots-based compositors
License:        MIT
Group:          System/Management
URL:            https://github.com/ammen99/wf-recorder
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.14

%description
Utility program for screen recording of wlroots-based compositors
(more specifically, those that support wlr-screencopy-v1 and xdg-output).

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%attr(0755,root,root) /usr/bin/wf-recorder
%{_mandir}/man?/%{name}*

%changelog
* Wed Aug 23 2023 ammen99@gmail.com
- Update to version 0.4.0+git0:
  * meson.build: bump version to 0.4.0
  * don't ask for overwrite for the char device (#141)
  * add --no-dmabuf option (#225)
  * Break early when exit_main_loop is set in encoder thread (#223)
  * Dynamically increase number of used buffers (#221)
  * Add X2RGB10 format mapping for DMA-BUFs (#224)
  * Add support for 16 bit deep formats (#184)
  * Revert "Use VP9+Opus on MKV for recordings"
  * Revert "Use VP8+Vorbis on WebM for recordings (#202)"
  * Use codec format which best matches input (#215)
  * Retry capture on failure
  * Use gbm_bo_create_with_modifiers when possible
  * Reduce memory usage with DMA-BUF capture (#219)
  * Use DMA-BUF with HW encoding (#206)
  * Only flush when video codec has delay (#209)
  * ci: add to safe directories so that git parse-rev works (#210)
* Tue Jan 17 2023 llyyr.public@gmail.com
- Update to version 0.3.0+git19:
  * Gracefully terminate on SIGTERM/SIGHUP to avoid corruption (#183)
  * Fix meson deprecation warning
  * Replace deprecated av_init_packet() calls
  * FrameRate Changes, Implement CFR and estimated buffer framerate (#190)
  * Use VP8+Vorbis on WebM for recordings (#202)
  * Add GitHub Actions CI to test the build (#201)
  * README: Flesh out build dependencies for building from source (#203)
  * build: Fix compile failure introduced by last commit (#200)
  * Add a compile-time option to set the default container file format
  * README: Update Fedora build and install documentation
  * Use VP9+Opus on MKV for recordings
  * Add default codec parameters for libvpx/libvpx-vp9. (#197)
* Tue Sep 13 2022 llyyr.public@gmail.com
- Update to version 0.3.0+git7:
  * fix formatting for muxer option in the manpage
  * Fix manpage formatting
  * remove redundant --force-yuv option
  * fix buffersink pix_fmt handling
  * docs: fix help and examples regarding -a & --audio (#180)
  * Remove unused variable (#178)
  * Support for configuring audio codec and video framerate (#177)
  * bump version in meson.build to 0.3.0
  * Fix: Crash when output is switched on (#168)
  * Add support for xrgb/xbgr 2101010 formats
* Wed Jun 29 2022 llyyr <thighsaspillows@gmail.com>
- Update to version v0.3.0
  * Support for ffmpeg filters with the -F <filter> option (5384bc9). This allows using many of the effects ffmpeg provides, see https://github.com/schauveau/wf-recorder-x for a good introduction on filters.
  * Support for recording new frames only when the screen contents actually change (#82). This is now the default behavior. If this is not desired (because for ex. the recording has variable refresh rate and not fixed), the -D option can be used to get the old behavior.
  * wf-recorder now asks the user if the output file will be overwritten (0b74ad4)
  * Various bug fixes, see the git log for complete list of changes.
* Tue Feb 16 2021 Denys Kondratenko <stdden@opensuse.org>
- fix for the issue #92 (Requested output format 'v4l2' is not a suitable output format)
  * adding missing libavdevice-devel dependency to be able to use v4l2loopback
* Fri Apr 17 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Update to version v0.2.1
  * Improved documentation
  * Fixed long recordings (>1h10m) (#78)
- Update to v0.2
  * Addition of manpage and help options #35
  * Conversion to RGB to YUV with the help of OpenCL (the latter being optional) #30 #32
  * Option to set muxer and pixel format #43 #53
  * Support for loopback devices: #43 #53
  * Update to newer avcodec_send_frame API #47
- Add opencl dependency for new OpenCL feature
- Add scdoc for man
- spec switched to %%meson macros
* Thu May 16 2019 Michael Aquilina <michaelaquilina@gmail.com>
- Initial Release
